@@ -1,7 +1,7 @@
 import test from 'ava';
-import m from './';
+import m from '.';
 
-test(t => {
+test('prepend http', t => {
 	t.is(m('todomvc.com'), 'http://todomvc.com');
 	t.is(m('http://todomvc.com'), 'http://todomvc.com');
 	t.is(m('https://todomvc.com'), 'https://todomvc.com');
@@ -15,3 +15,9 @@ test(t => {
 	t.is(m('mailto:info@site.com'), 'mailto:info@site.com');
 	t.is(m('tel:1234567890'), 'tel:1234567890');
 });
+
+test('https option', t => {
+	t.is(m('todomvc.com', {https: true}), 'https://todomvc.com');
+	t.is(m('//todomvc.com', {https: true}), '//todomvc.com');
+	t.is(m('localhost:8000', {https: true}), 'https://localhost:8000');
+});
